*:*****************************************************************************
*:  SAMPLE.PRG
*:*****************************************************************************

#include "common.ch"
#include "printer.ch"
static P_CODES[55],PRNT_SAVE[55],PRNT_HIDE[55]
static S_CODES[15],SLIP_SAVE[15]

*!*****************************************************************************
function PRINT_INIT( WHICH_PRNT )

local THIS_SET,x
local INAREA := select()

field printer

default WHICH_PRNT to 'PRINTER'

D_OPEN( 'PRINTER')

// get this machine's printer from the environment
if len(WHICH_PRNT) < 9
   THIS_SET := Gete( WHICH_PRNT )
else
   THIS_SET := WHICH_PRNT
endif

if !dbseek(THIS_SET) .or. empty(THIS_SET)
   dbseek('EPSON FX        ')     // use the default epson printer set
endif

for x := 1 to 55
   P_CODES[X] := PR_DECODE( fieldget( x ) )
next

PRNT_SAVE := aclone(P_CODES)
PRNT_HIDE := aclone(P_CODES)

for x := 1 to 55
   if ISCHAR( PRNT_HIDE[x] )
      PRNT_HIDE[X] := ''+PRNT_HIDE[X]+''
   endif
next

D_CLOSE("PRINTER")

select( INAREA )

return NIL

*!*****************************************************************************
function P_CODE(x)

return P_CODES[x]

*!*****************************************************************************
function PR_UNSET()

local x := P_CODES[47]
local Y := P_CODES[48]

Afill(P_CODES,'')

P_CODES[47] := x
P_CODES[48] := Y

return NIL

*!*****************************************************************************
function PR_RESET()

P_CODES := aclone(PRNT_SAVE)

return NIL

*!*****************************************************************************
function PR_HIDE()

P_CODES := aclone(PRNT_HIDE)

return NIL

*!*****************************************************************************
function SLIP_INIT()

local THIS_SET

D_OPEN('SLIP')

THIS_SET := Gete('SPRINTER')

if !dbseek(THIS_SET) .or. empty(THIS_SET) // use the default DP8340
   go 1
endif

for x := 1 to 15
   S_CODES[X] := PR_DECODE( fieldget( x ) )
next

SLIP_SAVE := aclone(S_CODES)

D_CLOSE('SLIP')

return NIL

*!*****************************************************************************
function S_CODE(x)

return S_CODES[x]

*!*****************************************************************************
function SL_UNSET()

local x := S_CODES[14]
local Y := S_CODES[15]

Afill(S_CODES,'')

S_CODES[14] := x
S_CODES[15] := Y

return NIL

*!*****************************************************************************
function SL_RESET()

S_CODES := aclone(SLIP_SAVE)

return NIL

*!*****************************************************************************
static function PR_DECODE( FIELD_DATA )

local OUT_STRING := ''
local SEP_AT, SEP_END, DEC_DATA

if ISLOGIC( FIELD_DATA )
   return FIELD_DATA
endif

if ISNUMBER( FIELD_DATA )
   return FIELD_DATA
endif

FIELD_DATA := alltrim( FIELD_DATA )

if len( FIELD_DATA ) > 0
   do while .t.
      SEP_AT := at( '{', FIELD_DATA )
      do case
      case SEP_AT == 0
         OUT_STRING += FIELD_DATA
         exit
      case SEP_AT == 1
         SEP_END := at( "}", FIELD_DATA )
         DEC_DATA := substr( FIELD_DATA, 2, SEP_END - 1 )
         OUT_STRING += chr( val( DEC_DATA ) )
         FIELD_DATA := substr( FIELD_DATA, SEP_END + 1 )
      case SEP_AT > 1
         OUT_STRING += left( FIELD_DATA, SEP_AT - 1 )
         FIELD_DATA := substr( FIELD_DATA, SEP_AT )
      endcase
   enddo
endif

return OUT_STRING

*!*****************************************************************************
function PRN_PICK

local MSG := {}

PUSH_ALL()

Cls()
D_OPEN('PRINTER')
set order to 1

LOOKPRN := HOTPICK(3,20,{"PRINTER"},"PRINTER",1,,'Select a Printer',,YOUR_PRINTER)

if !empty(LOOKPRN)
   Aadd(MSG,alltrim(LOOKPRN))
   Aadd(MSG,'')
   Aadd(MSG,'has been selected for testing ')
   Aadd(MSG,'')
   Aadd(MSG,'To permanently select this printer,')
   Aadd(MSG,'run SETUP from DOS and reselect this printer.')
   Aadd(MSG,'Otherwise, continue testing printers.')
   Aadd(MSG,'')
   Aadd(MSG,'Would you like to test this printer now?')
   if VERIFY(MSG,.t.,'Test','Ignore')
      PRINT_INIT(LOOKPRN)
      PRN_TEST()
   endif
endif

D_CLOSE('PRINTER')

POP_ALL()

return NIL

*!*****************************************************************************
function PRN_TEST

set printer (.t.)
set console (.f.)

ALIGN()
if lastkey() = 27
   return NIL
endif

? 'Test Printout for Printer ' + YOUR_PRINTER
?
?
? '( 3 skips )'
? CPI10S + 'This Line is Printed in 10 Characters Per Inch. It Should Not Over Run This Line'
? CPI12S + 'This Line is Printed in 12 Characters Per Inch................. It Should Not Over Run This Line'+CPI12E
? CPI15S + 'This Line is Printed in 15 Characters Per Inch......................................... It Should Not Over Run This Line'+CPI15E
? CPI17S + 'This Line is Printed in 17 Characters Per Inch......................................................... It Should Not Over Run This Line'+CPI17E
? NORMAL + 'Return to Normal Printing'
? DSS +    'Double Strike Start '  + DSE + 'then back to Normal'
? BPS +    'Bold Print Start '     + BPE + 'then back to Normal'
?
? DHS +    'Double Height Start '  + DHE + 'then back to Normal'
?
? EPS +    'Elongated Print Start '+ EPE + 'then back to Normal'
? IPS +    'Italic Print Start '   + IPE + 'then back to Normal'
? LQS +    'Letter Quality Start ' + LQE + 'then back to Normal'
? ULS +    'Underlined Start '     + ULE + 'then back to Normal'
?          'Double line'
? DOUBLELINE
?          'Single line'
? SINGLELINE
?
? SDP  +   'Double Height Double Width' + EDP
?
? SDPI +   'Double Height Double Width Italics' + EDPI
? NORMAL

// Maybe we do further testing .... what other codes do we use ?

? chr(12)

set printer (.f.)
set console (.t.)

return NIL

*: EOF: SAMPLE.PRG
